function ridgeStruct = specRidge(uTop,depthRidge)
% SPECRIDGE - returns velocity, pressure, \Grad P and coordinates for 2 or 3-D spectral ridge code
%   
%     ridgeStruct = specRidge(uTop,depthRidge)
%
%     Calculates: solid flow field and pressure for incompressible
%                 Stoke's flow in 2 or 3 Dimensions for an
%                 iso-viscous half-space driven by imposed flow on the upper boundary.
%                  
%                 Uses ffts in the horizontal so care needs to be taken to enforce periodicity
%                 and number of grid points (see setTopVelocity2D.m setTopVelocity3D.m for details)
%                 
%
%     uTop:     Structure produced from setTopVelocity2D or setTopVelocity3D
%                  uTop.nDims =2 or 3; check for dimensionality of problem
%                  uTop.u   2-D array with u(x,y,0) for top boundary
%                  uTop.uXPeriodic 1-D array that contains mean u(x)@z=0 
%                  uTop.indexPeriodic integer indices such that uTop.uXPeriodic(index) = mean(uTop.u) 
%                  uTop.x  x coordinates for 3-D domain
%                  uTop.y  y coordinates for 3-D domain
%                  utop.xPeriodic coordinates for extended 2-D periodic domaincontaining  U(x,y,0) of horizontal surface velocity. Full solution is assumed to reflect across yMax face
%                  utop.yPeriodic
%     depthRidge:      vector of depth coordinates (0 is the surface, z increases downwards)
%
%     ridgeStruct:  output structure for a 3-D ridge calculation (2-D problem neglect y,V)
%                     ridgeStruct.x:  x coordinates of solution domain
%                     ridgeStruct.y:  y coordinates of solution domain
%                     ridgeStruct.z:  z coordinates of solution domain
%                     ridgeStruct.u:  x velocity
%                     ridgeStruct.v:  y velocity
%                     ridgeStruct.w:  vertical velocity
%                     ridgeStruct.p:  scalar dynamic pressure field
%                     ridgeStruct.px: x dynamic pressure gradient (Delsq U)
%                     ridgeStruct.py: y dynamic pressure gradient (Delsq V)
%                     ridgeStruct.pz: vertical   dynamic pressure gradient (Delsq W)
   
% choose solver depending on nDim
   switch uTop.nDim
    case 2
     ridgeStruct = specRidge2D(uTop,depthRidge);
    case 3
     ridgeStruct = specRidge3D(uTop,depthRidge);
    otherwise
     error('uTop.nDim not defined')
   end
 
